package com.shzg.project.worn.service;

import java.util.List;
import com.shzg.project.worn.domain.WornDeclareItem;

/**
 * 申报单物料明细Service接口
 * 
 * @author shzg
 * @date 2026-04-14
 */
public interface IWornDeclareItemService 
{
    /**
     * 查询申报单物料明细
     * 
     * @param id 申报单物料明细主键
     * @return 申报单物料明细
     */
    public WornDeclareItem selectWornDeclareItemById(Long id);

    /**
     * 查询申报单物料明细列表
     * 
     * @param wornDeclareItem 申报单物料明细
     * @return 申报单物料明细集合
     */
    public List<WornDeclareItem> selectWornDeclareItemList(WornDeclareItem wornDeclareItem);

    /**
     * 新增申报单物料明细
     * 
     * @param wornDeclareItem 申报单物料明细
     * @return 结果
     */
    public int insertWornDeclareItem(WornDeclareItem wornDeclareItem);

    /**
     * 修改申报单物料明细
     * 
     * @param wornDeclareItem 申报单物料明细
     * @return 结果
     */
    public int updateWornDeclareItem(WornDeclareItem wornDeclareItem);

    /**
     * 批量删除申报单物料明细
     * 
     * @param ids 需要删除的申报单物料明细主键集合
     * @return 结果
     */
    public int deleteWornDeclareItemByIds(Long[] ids);

    /**
     * 删除申报单物料明细信息
     * 
     * @param id 申报单物料明细主键
     * @return 结果
     */
    public int deleteWornDeclareItemById(Long id);
}
