package com.shzg.project.worn.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.shzg.framework.aspectj.lang.annotation.Log;
import com.shzg.framework.aspectj.lang.enums.BusinessType;
import com.shzg.project.worn.domain.WornDeclareItem;
import com.shzg.project.worn.service.IWornDeclareItemService;
import com.shzg.framework.web.controller.BaseController;
import com.shzg.framework.web.domain.AjaxResult;
import com.shzg.common.utils.poi.ExcelUtil;
import com.shzg.framework.web.page.TableDataInfo;

/**
 * 申报单物料明细Controller
 * 
 * @author shzg
 * @date 2026-04-14
 */
@RestController
@RequestMapping("/worn/declareItem")
public class WornDeclareItemController extends BaseController
{
    @Autowired
    private IWornDeclareItemService wornDeclareItemService;

    /**
     * 查询申报单物料明细列表
     */
    @PreAuthorize("@ss.hasPermi('worn:declareItem:list')")
    @GetMapping("/list")
    public TableDataInfo list(WornDeclareItem wornDeclareItem)
    {
        startPage();
        List<WornDeclareItem> list = wornDeclareItemService.selectWornDeclareItemList(wornDeclareItem);
        return getDataTable(list);
    }

    /**
     * 导出申报单物料明细列表
     */
    @PreAuthorize("@ss.hasPermi('worn:declareItem:export')")
    @Log(title = "申报单物料明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WornDeclareItem wornDeclareItem)
    {
        List<WornDeclareItem> list = wornDeclareItemService.selectWornDeclareItemList(wornDeclareItem);
        ExcelUtil<WornDeclareItem> util = new ExcelUtil<WornDeclareItem>(WornDeclareItem.class);
        util.exportExcel(response, list, "申报单物料明细数据");
    }

    /**
     * 获取申报单物料明细详细信息
     */
    @PreAuthorize("@ss.hasPermi('worn:declareItem:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(wornDeclareItemService.selectWornDeclareItemById(id));
    }

    /**
     * 新增申报单物料明细
     */
    @PreAuthorize("@ss.hasPermi('worn:declareItem:add')")
    @Log(title = "申报单物料明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WornDeclareItem wornDeclareItem)
    {
        return toAjax(wornDeclareItemService.insertWornDeclareItem(wornDeclareItem));
    }

    /**
     * 修改申报单物料明细
     */
    @PreAuthorize("@ss.hasPermi('worn:declareItem:edit')")
    @Log(title = "申报单物料明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WornDeclareItem wornDeclareItem)
    {
        return toAjax(wornDeclareItemService.updateWornDeclareItem(wornDeclareItem));
    }

    /**
     * 删除申报单物料明细
     */
    @PreAuthorize("@ss.hasPermi('worn:declareItem:remove')")
    @Log(title = "申报单物料明细", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(wornDeclareItemService.deleteWornDeclareItemByIds(ids));
    }
}
